@@ -129,7 +129,7 @@ bool condition::wait(scoped_lock& l, duration const& timeout)
 	if (ms < 0) {
 		ms = 0;
 	}
-	bool const success = SleepConditionVariableCS(&cond_, l.m_, static_cast<DWORD>(timeout.get_milliseconds())) != 0;
+	bool const success = SleepConditionVariableCS(&cond_, l.m_, static_cast<DWORD>(ms)) != 0;
 #else
 	int res;
 	timespec ts;
